import 'package:gmo_cli/command/impl/args_mixin.dart';
import 'package:gmo_cli/common/utils/logger/log_utils.dart';
import 'package:gmo_cli/core/generator.dart';
import 'package:gmo_cli/core/internationalization.dart';
import 'package:gmo_cli/exception_handler/exceptions/cli_exception.dart';

abstract class Command with ArgsMixin {
  Command() {
    while (
        ((args.contains(commandName) || args.contains('$commandName:$name'))) &&
            args.isNotEmpty) {
      args.removeAt(0);
    }
    if (args.isNotEmpty && args.first == name) {
      args.removeAt(0);
    }
  }

  int get maxParameters;

  //int get minParameters;

  String? get codeSample;
  String get commandName;

  List<String> get alias => [];

  List<String> get acceptedFlags => [];

  /// hint for command line
  String? get hint;

  /// validate command line arguments
  bool validate() {
    if (GmoCli.arguments.contains(commandName) ||
        GmoCli.arguments.contains('$commandName:$name')) {
      var flagsNotAceppts = flags;
      flagsNotAceppts.removeWhere((element) => acceptedFlags.contains(element));
      if (flagsNotAceppts.isNotEmpty) {
        LogService.info('The %s is not necessary'.trArgsPlural(
          'The %s are not necessary',
          flagsNotAceppts.length,
          [flagsNotAceppts.toString()],
        )!);
      }

      if (args.length > maxParameters) {
        List pars = args.skip(maxParameters).toList();
        throw CliException(
            'the %s parameter is not necessary'.trArgsPlural(
              'the %s parameters are not necessary',
              pars.length,
              [pars.toString()],
            ),
            codeSample: codeSample);
      }
    }
    return true;
  }

  /// execute command
  Future<void> execute();

  /// childrens command
  List<Command> get childrens => [];
}
