import 'dart:io';

extension Trans on String {
  /// Translation
  String get tr => this;

  String trArgs([List<String?> args = const []]) {
    var key = tr;
    if (args.isNotEmpty) {
      for (final arg in args) {
        key = key.replaceFirst(RegExp(r'%s'), arg.toString());
      }
    }
    return key;
  }

  String? trPlural([String? plural, int i = 0]) {
    return i > 1 ? plural?.tr : tr;
  }

  String? trArgsPlural(
      [String? plural, int i = 0, List<String> args = const []]) {
    return i > 1 ? plural?.trArgs(args) : trArgs(args);
  }
}

extension _TranslationUtils on String {
  String get languageCode => split('_').first;
}

class Translation {
  final String _key;
  Translation(this._key);

  @override
  String toString() => tr;

  String get tr => _key.tr;

  String? trArgs([List<String>? args]) => _key.trArgs(args ?? []);
}
